require('dotenv').config();
const express = require('express');
const axios = require('axios');
const path = require('path');
const mysql = require('mysql');
const fs = require('fs');
const csv = require('csv-parser');
const bcrypt = require('bcrypt');
const saltRounds = 10;

const app = express();
const PORT = process.env.PORT || 80;

// Serve static files from the 'public' directory
app.use(express.static('public'));

// Middleware for parsing form data
app.use(express.urlencoded({ extended: true }));

// Serve the main HTML page
app.get('/', (req, res) => {
    res.sendFile(path.join(__dirname, 'index.html'));
});

// Database connection
const connection = mysql.createConnection({
    host: process.env.DB_HOST,
    user: process.env.DB_USER,
    password: process.env.DB_PASSWORD,
    database: process.env.DB_NAME
});

connection.connect((err) => {
    if (err) {
        console.error('Error connecting to the database:', err.stack);
        return;
    }
    console.log('Connected to the database as id ' + connection.threadId);
});

// Fetch fixtures and return them with team details from the API
let fixtureIds = []; // Store fixture IDs globally

app.get('/fixtures', async (req, res) => {
    const leagueId = '39'; // Example league ID
    const season = '2024'; // Example season
    const fromDate = '2024-08-29'; // Start date
    const toDate = '2024-10-31'; // End date

    try {
        const response = await axios.get('https://v3.football.api-sports.io/fixtures', {
            headers: {
                'x-rapidapi-key': process.env.RAPIDAPI_KEY,
                'x-rapidapi-host': 'v3.football.api-sports.io'
            },
            params: { league: leagueId, season, from: fromDate, to: toDate }
        });

        const fixtures = response.data.response.map(fixture => {
            return {
                id: fixture.fixture.id,
                fixture_date: fixture.fixture.date,
                home_team: {
                    id: fixture.teams.home.id,
                    name: fixture.teams.home.name,
                    logo: fixture.teams.home.logo
                },
                away_team: {
                    id: fixture.teams.away.id,
                    name: fixture.teams.away.name,
                    logo: fixture.teams.away.logo
                },
                league_id: leagueId,
                status: fixture.fixture.status.short,
                goals_home: fixture.goals.home,
                goals_away: fixture.goals.away,
                season
            };
        }).filter(fixture => fixture.home_team.id && fixture.away_team.id); // Ensure that neither team ID is null

        fixtureIds = fixtures.map(fixture => fixture.id); // Store the fixture IDs

        res.json({
            get: "fixtures",
            parameters: {
                league: leagueId,
                season: season
            },
            errors: [],
            results: fixtures.length,
            paging: {
                current: 1,
                total: 1
            },
            response: fixtures
        });
    } catch (error) {
        console.error('Error fetching fixtures from API-Football:', error.response ? error.response.data : error.message);
        res.status(500).send('Error fetching fixtures');
    }
});


app.get('/predictions/', async (req, res) => {
    try {
        const predictions = await Promise.all(
            fixtureIds.map(async (fixtureId) => {
                const response = await axios.get('https://v3.football.api-sports.io/predictions', {
                    headers: {
                        'x-rapidapi-key': process.env.RAPIDAPI_KEY,
                        'x-rapidapi-host': 'v3.football.api-sports.io'
                    },
                    params: { fixture: fixtureId }
                });

                return {
                    fixtureId: fixtureId,
                    data: response.data.response
                };
            })
        );

        res.json(predictions);
    } catch (error) {
        console.error('Error fetching predictions from API-Football:', error.response ? error.response.data : error.message);
        res.status(500).send('Error fetching predictions');
    }
});


// Handle user registration
app.post('/register', (req, res) => {
    const { username, password, email } = req.body;

    // Check if all fields are provided
    if (!username || !password || !email) {
        return res.status(400).send('Username, password, and email are required.');
    }

    // Hash the password
    bcrypt.hash(password, saltRounds, (err, hash) => {
        if (err) {
            console.error('Error hashing password:', err);
            return res.status(500).send('Error registering user');
        }

        // SQL query to insert user with email
        const query = 'INSERT INTO users (username, email, password) VALUES (?, ?, ?)';
        connection.query(query, [username, email, hash], (error) => {
            if (error) {
                console.error('Error inserting user:', error);
                return res.status(500).send('Error registering user');
            }
            res.redirect('/login');
        });
    });
});

// Start the server
app.listen(PORT, () => {
    console.log(`Server is running on http://localhost:${PORT}`);
});
