document.addEventListener('DOMContentLoaded', () => {
    const fixtureSelectContainer = document.getElementById('fixtureSelectContainer');

    const loadFixtures = () => {
        // Fetch and display fixtures
        fetch('/fixtures')
            .then(response => response.json())
            .then(data => {
                if (Array.isArray(data.response)) {
                    return data.response;
                } else {
                    throw new Error('Fixtures data is not an array');
                }
            })
            .then(fixtures => {
                fixtureSelectContainer.innerHTML = '';

                if (fixtures.length === 0) {
                    fixtureSelectContainer.innerHTML = '<p>No fixtures available at the moment.</p>';
                } else {
                    fixtures.forEach(fixture => {
                        const homeTeam = fixture.home_team.name;
                        const awayTeam = fixture.away_team.name;
                        const homeTeamLogo = fixture.home_team.logo;
                        const awayTeamLogo = fixture.away_team.logo;
                        const fixtureDate = fixture.fixture_date || 'Unknown Date';
                        const fixtureStatus = fixture.status || 'Unknown Status';

                        if (!homeTeam || !awayTeam) {
                            console.error('Missing team data for fixture:', fixture);
                            return;
                        }

                        const fixtureContainer = document.createElement('div');
                        fixtureContainer.className = 'fixture-container';

                        const fixtureButton = document.createElement('button');
                        fixtureButton.className = 'fixture-btn';
                        fixtureButton.innerHTML = `
                            <img src="${homeTeamLogo}" alt="${homeTeam} Logo" width="30">
                            ${homeTeam} vs 
                            <img src="${awayTeamLogo}" alt="${awayTeam} Logo" width="30">
                            ${awayTeam} - ${fixtureDate}<br>
                            Status: ${fixtureStatus}
                        `;

                        const predictionContainer = document.createElement('div');
                        predictionContainer.className = 'prediction-container';
                        fixtureContainer.appendChild(fixtureButton);
                        fixtureContainer.appendChild(predictionContainer);

                        // Automatically fetch and display predictions
                        fetch(`/predictions/${fixture.id}`)
                            .then(response => response.json())
                            .then(predictions => {
                                predictionContainer.innerHTML = ''; // Clear previous predictions

                                if (!Array.isArray(predictions) || predictions.length === 0) {
                                    predictionContainer.innerHTML = '<p>No predictions available for this fixture.</p>';
                                } else {
                                    const prediction = predictions[0];
                                    const winner = prediction.predictions?.winner?.name || 'Unknown';
                                    const advice = prediction.predictions?.advice || 'No advice';
                                    const percentHome = prediction.predictions?.percent?.home || 'N/A';
                                    const percentDraw = prediction.predictions?.percent?.draw || 'N/A';
                                    const percentAway = prediction.predictions?.percent?.away || 'N/A';
                                    const goalsPredictedHome = prediction.predictions?.goals?.home || 0;
                                    const goalsPredictedAway = prediction.predictions?.goals?.away || 0;

                                    predictionContainer.innerHTML = `
                                        <h3>Prediction:</h3>
                                        <p><strong>Winner:</strong> ${winner} (${advice})</p>
                                        <p><strong>Winning Chances:</strong></p>
                                        <ul>
                                            <li>Home: ${percentHome}</li>
                                            <li>Draw: ${percentDraw}</li>
                                            <li>Away: ${percentAway}</li>
                                        </ul>
                                        <p><strong>Goals Predicted:</strong></p>
                                        <p>Home: ${goalsPredictedHome}</p>
                                        <p>Away: ${goalsPredictedAway}</p>
                                        <p><strong>League:</strong> ${prediction.league?.name || 'Unknown'} (${prediction.league?.country || 'Unknown'})</p>
                                    `;
                                }
                            })
                            .catch(error => {
                                predictionContainer.textContent = 'Error fetching predictions';
                                console.error('Error fetching predictions:', error);
                            });

                        fixtureSelectContainer.appendChild(fixtureContainer);
                    });
                }
            })
            .catch(error => {
                fixtureSelectContainer.textContent = 'Error fetching fixtures';
                console.error('Error fetching fixtures:', error);
            });
    };

    const initModals = () => {
        const registerModal = document.getElementById('registerModal');
        const loginModal = document.getElementById('loginModal');
        const signUpBtn = document.getElementById('signUpBtn');
        const loginBtn = document.getElementById('loginBtn');
        const closeRegister = document.getElementById('closeRegister');
        const closeLogin = document.getElementById('closeLogin');

        // Open Registration Modal
        signUpBtn.addEventListener('click', () => {
            registerModal.style.display = 'block';
        });

        // Open Login Modal
        loginBtn.addEventListener('click', () => {
            loginModal.style.display = 'block';
        });

        // Close Registration Modal
        closeRegister.addEventListener('click', () => {
            registerModal.style.display = 'none';
        });

        // Close Login Modal
        closeLogin.addEventListener('click', () => {
            loginModal.style.display = 'none';
        });

        // Close Modals when clicking outside of them
        window.addEventListener('click', (event) => {
            if (event.target === registerModal) {
                registerModal.style.display = 'none';
            }
            if (event.target === loginModal) {
                loginModal.style.display = 'none';
            }
        });

        // Handle login form submission
        const loginForm = document.getElementById('loginForm');
        if (loginForm) {
            loginForm.addEventListener('submit', async (e) => {
                e.preventDefault();
                const formData = new FormData(loginForm);
                const data = Object.fromEntries(formData);

                try {
                    const response = await fetch('/login', {
                        method: 'POST',
                        headers: {
                            'Content-Type': 'application/json'
                        },
                        body: JSON.stringify(data),
                    });

                    const result = await response.json();

                    if (response.ok) {
                        alert('Login successful!');
                        loginModal.style.display = 'none';
                        // You can redirect or perform other actions here
                    } else {
                        alert(`Login failed: ${result.message || 'Unknown error'}`);
                    }
                } catch (error) {
                    console.error('Error during login:', error);
                    alert('Login failed due to a network error.');
                }
            });
        }
    };

    // Initialize all functions
    const init = () => {
        loadFixtures();
        initModals();
    };

    init();
});
