const axios = require('axios');
const mysql = require('mysql');
require('dotenv').config();

// Database connection
const connection = mysql.createConnection({
    host: process.env.DB_HOST,
    user: process.env.DB_USER,
    password: process.env.DB_PASSWORD,
    database: process.env.DB_NAME
});

connection.connect((err) => {
    if (err) {
        console.error('Error connecting to the database:', err.stack);
        return;
    }
    console.log('Connected to the database as id ' + connection.threadId);
});

// Function to fetch and save fixtures for a specific league and season
async function fetchAndSaveLeagueFixtures(leagueId, seasonId) {
    const fixturesApiUrl = 'https://api.sportmonks.com/v3/football/fixtures';

    try {
        const response = await axios.get(fixturesApiUrl, {
            params: {
                api_token: process.env.SPORTMONKS_API_KEY,
                leagues: leagueId,
                seasons: seasonId,
            }
        });

        const fixtures = response.data.data;

        // Insert fixtures into the database
        fixtures.forEach(fixture => {
            const fixtureDate = fixture.time && fixture.time.starting_at ? fixture.time.starting_at.date : '1970-01-01';

            // Ensure both home_team_id and away_team_id are not null
            const homeTeamId = fixture.localteam_id || null;
            const awayTeamId = fixture.visitorteam_id || null;

            if (!homeTeamId || !awayTeamId) {
                console.warn(`Fixture ${fixture.id} does not have a valid home_team_id or away_team_id. Skipping...`);
                return;
            }

            const query = `
                INSERT INTO fixtures (id, fixture_date, home_team_id, away_team_id, league_id, venue, status)
                VALUES (?, ?, ?, ?, ?, ?, ?)
                ON DUPLICATE KEY UPDATE
                fixture_date = VALUES(fixture_date),
                home_team_id = VALUES(home_team_id),
                away_team_id = VALUES(away_team_id),
                league_id = VALUES(league_id),
                venue = VALUES(venue),
                status = VALUES(status);
            `;
            const values = [
                fixture.id,
                fixtureDate,
                homeTeamId,
                awayTeamId,
                fixture.league_id,
                fixture.venue ? fixture.venue.name : null,
                fixture.status
            ];

            connection.query(query, values, (error) => {
                if (error) {
                    console.error('Error inserting fixture:', error);
                }
            });
        });

        console.log(`Fixtures for league ${leagueId} and season ${seasonId} fetched and stored successfully.`);
    } catch (error) {
        console.error('Error fetching league fixtures:', error);
    } finally {
        connection.end();
    }
}

// Fetch and save fixtures for league 2 and season 23619
fetchAndSaveLeagueFixtures(2, 23619);
